# iMOD-coupler
![Continuous integration](https://github.com/Deltares/imod_coupler/workflows/Continuous%20integration/badge.svg)
[![codecov](https://codecov.io/gh/Deltares/imod_coupler/branch/master/graph/badge.svg)](https://codecov.io/gh/Deltares/imod_coupler)

The `imod_coupler` is used to couple hydrological kernels.
It can be installed by running
```
pip install imod_coupler
```

Then you can run it as command line app via
```
imodc
```
In order to receive help for its usage, run 
```
imodc --help
```

The `imod_coupler` can also be imported within Python via
```python
import imod_coupler
```
